@@ -40,7 +40,7 @@ class AsyncSearchClient(NamespacedClient):
         Deletes an async search by ID. If the search is still running, the search request
         will be cancelled. Otherwise, the saved search results are deleted.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.0/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
 
         :param id: The async search ID
         """
@@ -71,16 +71,18 @@ class AsyncSearchClient(NamespacedClient):
             t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
         ] = None,
         human: t.Optional[bool] = None,
-        keep_alive: t.Optional[t.Union[int, str]] = None,
+        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         pretty: t.Optional[bool] = None,
         typed_keys: t.Optional[bool] = None,
-        wait_for_completion_timeout: t.Optional[t.Union[int, str]] = None,
+        wait_for_completion_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Retrieves the results of a previously submitted async search request given its
         ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.0/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
 
         :param id: The async search ID
         :param keep_alive: Specify the time interval in which the results (partial or
@@ -129,7 +131,7 @@ class AsyncSearchClient(NamespacedClient):
         Retrieves the status of a previously submitted async search request given its
         ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.0/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
 
         :param id: The async search ID
         """
@@ -211,8 +213,9 @@ class AsyncSearchClient(NamespacedClient):
         indices_boost: t.Optional[
             t.Union[t.List[t.Mapping[str, float]], t.Tuple[t.Mapping[str, float], ...]]
         ] = None,
-        keep_alive: t.Optional[t.Union[int, str]] = None,
+        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         keep_on_completion: t.Optional[bool] = None,
+        knn: t.Optional[t.Mapping[str, t.Any]] = None,
         lenient: t.Optional[bool] = None,
         max_concurrent_shard_requests: t.Optional[int] = None,
         min_compatible_shard_node: t.Optional[str] = None,
@@ -249,7 +252,7 @@ class AsyncSearchClient(NamespacedClient):
             ]
         ] = None,
         script_fields: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
-        scroll: t.Optional[t.Union[int, str]] = None,
+        scroll: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         search_after: t.Optional[
             t.Union[
                 t.List[t.Union[None, float, int, str]],
@@ -295,12 +298,14 @@ class AsyncSearchClient(NamespacedClient):
         track_total_hits: t.Optional[t.Union[bool, int]] = None,
         typed_keys: t.Optional[bool] = None,
         version: t.Optional[bool] = None,
-        wait_for_completion_timeout: t.Optional[t.Union[int, str]] = None,
+        wait_for_completion_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Executes a search request asynchronously.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.0/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
 
         :param index: A comma-separated list of index names to search; use `_all` or
             empty string to perform the operation on all indices
@@ -346,6 +351,7 @@ class AsyncSearchClient(NamespacedClient):
         :param keep_on_completion: Control whether the response should be stored in the
             cluster if it completed within the provided [wait_for_completion] time (default:
             false)
+        :param knn: Defines the approximate kNN search to run.
         :param lenient: Specify whether format-based query failures (such as providing
             text to a numeric field) should be ignored
         :param max_concurrent_shard_requests: The number of concurrent shard requests
@@ -427,6 +433,17 @@ class AsyncSearchClient(NamespacedClient):
             __path = "/_async_search"
         __body: t.Dict[str, t.Any] = {}
         __query: t.Dict[str, t.Any] = {}
+        # The 'sort' parameter with a colon can't be encoded to the body.
+        if sort is not None and (
+            (isinstance(sort, str) and ":" in sort)
+            or (
+                isinstance(sort, (list, tuple))
+                and all(isinstance(_x, str) for _x in sort)
+                and any(":" in _x for _x in sort)
+            )
+        ):
+            __query["sort"] = sort
+            sort = None
         if aggregations is not None:
             __body["aggregations"] = aggregations
         if aggs is not None:
@@ -477,6 +494,8 @@ class AsyncSearchClient(NamespacedClient):
             __query["keep_alive"] = keep_alive
         if keep_on_completion is not None:
             __query["keep_on_completion"] = keep_on_completion
+        if knn is not None:
+            __body["knn"] = knn
         if lenient is not None:
             __query["lenient"] = lenient
         if max_concurrent_shard_requests is not None:
